@@ -1,6 +1,6 @@
 package Dancer2::Plugin::DBIC;
 
-our $VERSION = '0.0013'; # VERSION
+our $VERSION = '0.0014'; # VERSION
 
 use strict;
 use warnings;
@@ -50,12 +50,12 @@ Dancer2::Plugin::DBIC - DBIx::Class interface for Dancer2 applications
 
 =head1 VERSION
 
-version 0.0013
+version 0.0014
 
 =head1 SYNOPSIS
 
     use Dancer2;
-    use Dancer2::Plugin::DBIC qw(schema resultset rset);
+    use Dancer2::Plugin::DBIC;
 
     get '/users/:user_id' => sub {
         my $user = schema('default')->resultset('User')->find(param 'user_id');
@@ -79,6 +79,7 @@ This plugin makes it very easy to create L<Dancer2> applications that interface
 with databases.
 It automatically exports the keyword C<schema> which returns a
 L<DBIx::Class::Schema> object.
+It also exports the keywords C<resultset> and C<rset>.
 You just need to configure your database connection information.
 For performance, schema objects are cached in memory
 and are lazy loaded the first time they are accessed.
